==> volsite_postgres_common-0.0.13.tar.gz: volsite_postgres_common-0.0.13/src/volsite_postgres_common/api/CA.py <==
from typing import Final


# ====== CA: Common Attribute ======

class CA:
    Api: Final[str] = "api"
    Auth: Final[str] = "aut"
    Ascending: Final[str] = "asc"  # in SQL

    Check: Final[str] = "chk"
    Click: Final[str] = "clk"
    Code: Final[str] = "cd"
    Collect: Final[str] = "clt"
    Collected: Final[str] = "cltd"
    Color: Final[str] = "col"
    Count: Final[str] = "cnt"
    Create: Final[str] = "ct"
    CreateTime: Final[str] = "crt"

    Data: Final[str] = "dt"
    Descending: Final[str] = "desc"  # in SQL
    Description: Final[str] = "des"
    DescriptionFormatted: Final[str] = "desf"
    DescriptionId: Final[str] = "desid"
    DescriptionPlain: Final[str] = "desp"

    Finished: Final[str] = "fied"

    Head: Final[str] = "hd"
    HeadVersion: Final[str] = "hv"

    Id: Final[str] = "id"
    Info: Final[str] = "inf"

    List: Final[str] = "lt"
    Login: Final[str] = "lgn"

    Name: Final[str] = "na"
    Note: Final[str] = "nt"

    Password: Final[str] = "pw"
    Public: Final[str] = "pb"

    Request: Final[str] = "rqt"
    Result: Final[str] = "ret"

    Signup: Final[str] = "sgu"
    SortBy: Final[str] = "stby"
    SortDirection: Final[str] = "stdr"
    Stars: Final[str] = "strs"
    Start: Final[str] = "str"
    State: Final[str] = "ste"

    Text: Final[str] = "txt"
    Time: Final[str] = "tm"
    TimeZone: Final[str] = "tmz"
    Title: Final[str] = "tt"
    TitleId: Final[str] = "ttid"
    Type: Final[str] = "tp"

    Update: Final[str] = "ud"
    UpdateTime: Final[str] = "udt"
    Used: Final[str] = "used"
    User: Final[str] = "usr"
    UserId: Final[str] = "uid"

    Version: Final[str] = "vn"
    VersionCreate: Final[str] = "vct"
    VersionId: Final[str] = "vid"
    Visited: Final[str] = "vst"
    Visiting: Final[str] = "vstng"

    Word: Final[str] = "w"

    ___Error___: Final[str] = "err"

==> volsite_postgres_common-0.0.16.tar.gz: volsite_postgres_common-0.0.16/src/volsite_postgres_common/api/CA.py <==
from typing import Final


# ====== CA: Common Attribute ======

class CA:
    Api: Final[str] = "api"
    Auth: Final[str] = "aut"
    Ascending: Final[str] = "asc"  # in SQL

    Book: Final[str] = "b"
    BookId: Final[str] = "bid"
    BookChapterVersionComboId: Final[str] = "bcvcid"
    BookVersion: Final[str] = "bv"
    BookVersionId: Final[str] = "bvid"

    Check: Final[str] = "chk"
    Chapter: Final[str] = "c"
    ChapterVersion: Final[str] = "cv"
    ChapterVersionId: Final[str] = "cvid"
    Click: Final[str] = "clk"
    Code: Final[str] = "cd"
    Collect: Final[str] = "clt"
    Collected: Final[str] = "cltd"
    Color: Final[str] = "col"
    Count: Final[str] = "cnt"
    Create: Final[str] = "ct"
    CreateTime: Final[str] = "crt"

    Data: Final[str] = "dt"
    Descending: Final[str] = "desc"  # in SQL
    Description: Final[str] = "des"
    DescriptionFormatted: Final[str] = "desf"
    DescriptionId: Final[str] = "desid"
    DescriptionPlain: Final[str] = "desp"

    Finished: Final[str] = "fied"

    Head: Final[str] = "hd"
    HeadVersion: Final[str] = "hv"

    Id: Final[str] = "id"
    Info: Final[str] = "inf"

    LearnerId: Final[str] = "lrid"
    List: Final[str] = "lt"
    Login: Final[str] = "lgn"

    MentorId: Final[str] = "mrid"

    Name: Final[str] = "na"
    Note: Final[str] = "nt"

    Parameter: Final[str] = "pm"
    Password: Final[str] = "pw"
    Private: Final[str] = "pvt"
    Public: Final[str] = "pb"

    Request: Final[str] = "rqt"
    Result: Final[str] = "ret"

    Sentence: Final[str] = "sn"
    SentenceAudio: Final[str] = "sa"
    SentenceAudioId: Final[str] = "said"
    SentenceId: Final[str] = "snid"
    Series: Final[str] = "ses"
    Signup: Final[str] = "sgu"
    Size: Final[str] = "siz"
    SortBy: Final[str] = "stby"
    SortDirection: Final[str] = "stdr"
    Stars: Final[str] = "strs"
    Start: Final[str] = "str"
    State: Final[str] = "ste"

    Text: Final[str] = "txt"
    Time: Final[str] = "tm"
    TimeZone: Final[str] = "tmz"
    Title: Final[str] = "tt"
    TitleId: Final[str] = "ttid"
    Type: Final[str] = "tp"

    Update: Final[str] = "ud"
    UpdateTime: Final[str] = "udt"
    Used: Final[str] = "used"
    User: Final[str] = "usr"
    UserId: Final[str] = "uid"

    Version: Final[str] = "vn"
    VersionCreate: Final[str] = "vct"
    VersionId: Final[str] = "vid"
    Visited: Final[str] = "vst"
    Visiting: Final[str] = "vstng"

    Word: Final[str] = "w"
    WordId: Final[str] = "wid"

    ___Error___: Final[str] = "err"
